(function($) {
  // Global variable
  var innerMenuSticky = false;

  initComponents();

  /**
   * Initialize web components
   */
  function initComponents() {
    fonts();
    stickyInnerMenu(); // inner page menu
    smoothScroll();
    carousel('.js-banner', {
      singleItem: true,
      transitionStyle: 'funasaka-fade',
      loop: true,
      mouseDrag: false,
      touchDrag: false,
      autoPlay: 6000,
      navigation: false
    });
    carousel('.js-carousel', {
      items: 4,
      autoPlay: true,
      stopOnHover: true,
      navigation: false,
      pagination: false
    });
    parallax();
    // lightbox2();
    popup();
    siteInfo();
    $(window).resize(); // fire resize event
  }

  /**
   * Window load event listener
   */
  $(window).load(function() {
    initZF(); // Zurb Foundation v6.2.4

    $('.js-loading__inner').fadeOut('slow', function() {
      var timer = setInterval(function() {

        $('.js-loading').fadeOut(300, function() {
          clearInterval(timer);
        });

        animate();
        $(document.body).removeClass('init'); // remove '.init' body class

      }, 100);
    });
  });

  /**
   * Initialize Zurb Foundation v6.2.4 components
   */
  function initZF() {
    // check for foundation
    if($().foundation) {
      $(document).foundation();
    }
  }

  /**
   * Font face observer. Listens for fonts being loaded, and notifies when downloaded and failed.
   */
  function fonts() {
    // check for FontFaceObserver
    if(window.FontFaceObserver) {
      var $body = $(document.body); // document body
      var lato = new FontFaceObserver('Lato');
      var playfairDisplay = new FontFaceObserver('Playfair Display');
      var manus = new FontFaceObserver('Manus');

      // listens for Lato font
      lato.load(null, 5000).then(function() {
        $body.addClass('lato'); // add '.lato' class to the document body
      });

      // listens for Playfair Display font
      playfairDisplay.load(null, 5000).then(function() {
        $body.addClass('playfair-display'); // add '.playfair-display' class to the document body
      });

      // listens for Manus font
      manus.load(null, 5000).then(function() {
        $body.addClass('manus'); // add '.manus' class to the document body
      });
    }
  }

  /**
   * Sticky inner page menu on scroll.
   */
  function stickyInnerMenu() {
    // get current scroll top position + the main header height
    var scrollTop = $(window).scrollTop() + getHeaderHeight();
    var $innerMenu = $('.js-menu-inner-wrapper'); // jQuery wrapper

    if($innerMenu.length === 0) return; // if element doesn't exist, exit method.

    var innerMenuTopPos = $innerMenu.position().top; // inner menu top position

    toggleInnerMenuStickiness();
    internalLinksHighlight();

    // window scroll event listner
    $(window).scroll(function() {
      // update on the latest scroll top position + the main header height
      scrollTop = $(this).scrollTop() + getHeaderHeight();
      toggleInnerMenuStickiness();
      internalLinksHighlight();
    });

    /* toggle inner menu stickiness */
    function toggleInnerMenuStickiness() {
      if(scrollTop >= innerMenuTopPos && !innerMenuSticky) {
        $innerMenu.addClass('sticky'); // add class .sticky
        $innerMenu.css('top', getHeaderHeight() + 'px');
        $(document.body).css('paddingTop', getInnerMenuHeight() + 'px');

        innerMenuSticky = true;
      } else if(scrollTop < innerMenuTopPos && innerMenuSticky) {
        $innerMenu.removeClass('sticky');
        $(document.body).removeAttr('style');

        innerMenuSticky = false;
      }
    }

    /* Make internal links be highlighted when the corresponding section is being hit */
    function internalLinksHighlight() {
        var menuItems       = $('.menu.menu--inner > li > a[href^="#"]');

        $('[data-magellan-target]').each(function(i) {
            var sectionTopPos   = $(this).position().top;
            var sectionId       = $(this).attr('id');
            if(sectionTopPos <= scrollTop + getHeaderHeight()) {
                $(menuItems).removeClass('active');
                $('.menu.menu--inner > li > a[href^="#' + sectionId + '"]').addClass('active');
            }
        });
    }
  }

  /**
   * Smooth scrolling.
   */
  function smoothScroll() {
    $('a[href*="#"]:not([href="#"]):not([href^="#popup"])').click(function() {
      if (location.pathname.replace(/^\//,'') == this.pathname.replace(/^\//,'') && location.hostname == this.hostname) {
        var target = $(this.hash);
        target = target.length ? target : $('[name=' + this.hash.slice(1) +']');
        if (target.length) {
          $('html, body').animate({
            scrollTop: target.offset().top - (getHeaderHeight() + getInnerMenuHeight())
          }, 1000);
          return false;
        }
      }
    });
  }

  /**
   * Create a carousel using OwlCarousel v1.3.2
   *
   * @param {String} elem - The target element.
   * @param {Object} options - The configuration options for creating a carousel.
   */
  function carousel(elem, options) {
    // check for owlCarousel
    if($().owlCarousel) {
      $elem = $(elem);

      if(options.singleItem && options.singleItem === true) {
        if($elem.children().length < 2) {
          options.autoPlay = false;
        }
      }

      $elem.owlCarousel(options);

      // click handler for prev button
      $('.js-arrow--prev').click(function(e) {
        $elem.trigger('owl.prev');

        e.preventDefault();
      });

      // click hander for next button
      $('.js-arrow--next').click(function(e) {
        $elem.trigger('owl.next');

        e.preventDefault();
      });
    }

  }

  /**
   * Parallax using stellar.js
   */
  function parallax() {
    // check for stellar
    if($().stellar) {
      $(window).stellar({
        horizontalScrolling: false,
        positionProperty: 'transform',
        parallaxBackgrounds: false,
        hideDistantElements: false
      });
    }
  }

  /**
   * Lightbox2 configuration
   */
  function lightbox2() {
    // check for lightbox
    if(window.lightbox) {
      lightbox.option({
        alwaysShowNavOnTouchDevices: true,
        positionFromTop: getHeaderHeight(),
        wrapAround: true
      });
    }
  }

  /**
   * Popup for images and videos.
   */
  function popup() {
    // check for magnificPopup
    if($().magnificPopup) {
      // default options
      var options = {
        fixedContentPos: false,
        autoFocusLast: false,
        removalDelay: 300,
        closeBtnInside: false,
        callbacks: {
          beforeOpen: function() {
            // just a hack that adds mfp-anim class to markup 
            this.st.mainClass = 'mfp-zoom-in';
          },

          open: function() {            
            if(this.currItem.inlineElement !== undefined) {
              var $video = $(this.currItem.inlineElement).find('video');
              
              var timer = setInterval(function() {
                $video[0].play();
                clearInterval(timer);
              }, 2000);
            }
          },

          close: function() {          
            if(this.currItem.inlineElement !== undefined) {
              var $video = $(this.currItem.inlineElement).find('video');
              $video[0].pause();
            }
          }
        }
      };

      $('.js-popup--image').magnificPopup(options);

      // gallery enabled
      options.gallery = {
        enabled: true,
        tPrev: '', // title for left button
        tNext: ''
      };

      $('.js-popup--gallery').magnificPopup(options);
    }
  }

  /**
   * Animation using Wow.js and Animate.css
   */
  function animate() {
    // check for WOW
    if(window.WOW) {
      var wow = new WOW({
        boxClass:     'wow',      // animated element css class (default is wow)
        animateClass: 'animated', // animation css class (default is animated)
        offset:       0,          // distance to the element when triggering the animation (default is 0)
        mobile:       true,       // trigger animations on mobile devices (default is true)
        live:         true,       // act on asynchronously loaded content (default is true)
        callback:     function(box) {
          // the callback is fired every time an animation is started
          // the argument that is passed in is the DOM node being animated
        },
        scrollContainer: null // optional scroll container selector, otherwise use window
      });
      wow.init();
    }
  }

  /**
   * Return the height of the window.
   *
   * @return {int} - The height of the window.
   */
  function getWindowHeight() {
    return $(window).height();
  }

  /**
   * Return the height of the main header.
   *
   * @return {int} - The height of the element
   */
  function getHeaderHeight() {
    return $('#container > header').innerHeight();
  }

  /**
   * Return inner page menu height.
   *
   * @return {int} - The height of the inner page menu.
   */
   function getInnerMenuHeight() {
     return $('.js-menu-inner-wrapper').innerHeight(); // return the height of the element
   }

  /**
   * Return the height of the main footer.
   *
   * @return {int} - The height of the element
   */
  function getFooteHeight() {
    return $('#container > footer').innerHeight();
  }

  /**
   * Shorthand for console.log
   *
   * @param {String} $message - The message to log.
   */
  function log(message) {
    console.log(message); // log the message
  }

  /**
   * Log the general website information.
   */
  function siteInfo() {
    // Check for console.message
    if(console.message) {
      var siteTitle = $(document.body).data('site-name');
      var siteDescription = $(document.body).data('site-description');
      var siteCopyright = $('.js-copyright').html();

      var decode = document.createElement("div");
      decode.innerHTML = siteCopyright;

      siteCopyright = decode.childNodes[0].nodeValue;

      siteTitle = siteTitle.toUpperCase();

      // log site title
      console
      .message()
      .text(siteTitle, {
        fontSize: '42px',
        color: '#2a2a2a',
        fontFamily: '\'Playfail Display\', serif'
       })
     .print();

     // log site description
     console
     .message()
     .text(siteDescription, {
       fontSize: '1rem',
       color: '#2a2a2a',
       fontFamily: '\'Lato\', sans-serif'
      })
      .print();

      log(''); // new line
      log(siteCopyright); // log site copyright
     }
   }
})(jQuery);
