<?php
/* Welcome to Kalabera :)

Filename: kalabera.php
Desciption: This is the core Kalabera file where most of the main functions & features reside.
If you have any custom functions, it's best to put them in the functions.php file.

Author: den.isahac
Author URI: https://github.com/denisahac

- head cleanup (remove rsd, uri links, junk css, ect)
- enqueueing scripts & styles
- theme support functions
- custom menu output & fallbacks
- related post function
- page-navi function
- removing <p> from around images
- customizing the post excerpt
*/

/*********************
WP_HEAD GOODNESS
The default wordpress head is
a mess. Let's clean it up by
removing all the junk we don't
need.
*********************/

function bones_head_cleanup() {
	// category feeds
	// remove_action( 'wp_head', 'feed_links_extra', 3 );
	// post and comment feeds
	// remove_action( 'wp_head', 'feed_links', 2 );
	// EditURI link
	remove_action( 'wp_head', 'rsd_link' );
	// windows live writer
	remove_action( 'wp_head', 'wlwmanifest_link' );
	// previous link
	remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
	// start link
	remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
	// links for adjacent posts
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
	// WP version
	remove_action( 'wp_head', 'wp_generator' );
	// remove WP version from css
	add_filter( 'style_loader_src', 'bones_remove_wp_ver_css_js', 9999 );
	// remove Wp version from scripts
	add_filter( 'script_loader_src', 'bones_remove_wp_ver_css_js', 9999 );

} /* end bones head cleanup */

// A better title
// http://www.deluxeblogtips.com/2012/03/better-title-meta-tag.html
function rw_title( $title, $sep, $seplocation ) {
  global $page, $paged;

  // Don't affect in feeds.
  if ( is_feed() ) return $title;

  // Add the blog's name
  if ( 'right' == $seplocation ) {
    $title .= get_bloginfo( 'name' );
  } else {
    $title = get_bloginfo( 'name' ) . $title;
  }

  // Add the blog description for the home/front page.
  $site_description = get_bloginfo( 'description', 'display' );

  if ( $site_description && ( is_home() || is_front_page() ) ) {
    $title .= " {$sep} {$site_description}";
  }

  // Add a page number if necessary:
  if ( $paged >= 2 || $page >= 2 ) {
    $title .= " {$sep} " . sprintf( __( 'Page %s', 'dbt' ), max( $paged, $page ) );
  }

  return $title;

} // end better title

// remove WP version from RSS
function bones_rss_version() { return ''; }

// remove WP version from scripts
function bones_remove_wp_ver_css_js( $src ) {
	if ( strpos( $src, 'ver=' ) )
		$src = remove_query_arg( 'ver', $src );
	return $src;
}

// remove injected CSS for recent comments widget
function bones_remove_wp_widget_recent_comments_style() {
	if ( has_filter( 'wp_head', 'wp_widget_recent_comments_style' ) ) {
		remove_filter( 'wp_head', 'wp_widget_recent_comments_style' );
	}
}

// remove injected CSS from recent comments widget
function bones_remove_recent_comments_style() {
	global $wp_widget_factory;
	if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
		remove_action( 'wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style') );
	}
}

// remove injected CSS from gallery
function bones_gallery_style($css) {
	return preg_replace( "!<style type='text/css'>(.*?)</style>!s", '', $css );
}


/*********************
SCRIPTS & ENQUEUEING
*********************/

// loading modernizr and jquery, and reply script
function bones_scripts_and_styles() {
	// fonts
	wp_enqueue_style('fonts', '//fonts.googleapis.com/css?family=Lato|Playfair+Display');

  if (!is_admin()) {
		if(WP_DEBUG == true) {
			developmnet_assets();
		} else {
			production_assets();
		}
	}
}

/**
 * Development assets
 */
function developmnet_assets() {
	// jQuery
	wp_deregister_script('jquery');
	wp_deregister_script('jquery-migrate');
	wp_enqueue_script('jquery', get_stylesheet_directory_uri() . '/library/components/jquery/dist/jquery.min.js', array(), '2.2.4', true);
	// FontFaceObserver
	wp_enqueue_script('fontfaceobserver', get_stylesheet_directory_uri() . '/library/components/fontfaceobserver/fontfaceobserver.js', array(), '2.0.7', true);
	// console message
	wp_enqueue_script('console-message', get_stylesheet_directory_uri() . '/library/components/console.message/console.message.min.js', array(), '0.1.0', true);
	// smooth scroll
	wp_enqueue_script('smoothscroll', get_stylesheet_directory_uri() . '/library/js/lib/smoothscroll.min.js', array('jquery'), wp_get_theme()->get('Version'), true);
	// Zurb Foundation v6.2.4
	$zf_version = '6.2.4';
	wp_enqueue_script('zf-core', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.core.js', array('jquery'), $zf_version, true);
	wp_enqueue_script('zf-util-keyboard', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.keyboard.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-box', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.box.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-nest', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.nest.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-mq', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.mediaQuery.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-tail', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.timerAndImageLoader.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-motion', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.motion.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-util-triggers', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.util.triggers.js', array('zf-core'), $zf_version, true);
	wp_enqueue_script('zf-dropdown-menu', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.dropdownMenu.js', array('zf-util-keyboard', 'zf-util-box', 'zf-util-nest', 'zf-util-mq'), $zf_version, true);
	wp_enqueue_script('zf-equalizer', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.equalizer.js', array('zf-util-mq', 'zf-util-tail'), $zf_version, true);
	wp_enqueue_script('zf-toggler', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.toggler.js', array('zf-util-motion', 'zf-util-triggers'), $zf_version, true);
	wp_enqueue_script('zf-responsive-toggle', get_stylesheet_directory_uri() . '/library/components/foundation-sites/dist/js/plugins/foundation.responsiveToggle.js', array('zf-util-mq'), $zf_version, true);
	// Owl carousel
	$owl_version = '1.3.2';
	wp_enqueue_style('owl', get_stylesheet_directory_uri() . '/library/components/OwlCarousel/owl-carousel/owl.carousel.css', array(), $owl_version, 'screen');
	wp_enqueue_style('owl-transitions', get_stylesheet_directory_uri() . '/library/components/OwlCarousel/owl-carousel/owl.transitions.css', array('owl'), $owl_version, 'screen');
	wp_enqueue_script('owl', get_stylesheet_directory_uri() . '/library/components/OwlCarousel/owl-carousel/owl.carousel.min.js', array('jquery'), $owl_version, true);
	// Magnific Popup
	$magnific_version = '1.1.0';
	wp_enqueue_script('magnific', get_stylesheet_directory_uri() . '/library/components/magnific-popup/dist/jquery.magnific-popup.min.js', array('jquery'), $magnific_version, true);
	wp_enqueue_style('magnific', get_stylesheet_directory_uri() . '/library/components/magnific-popup/dist/magnific-popup.css', array(), $magnific_version, 'screen');
	// Images loaded
	wp_enqueue_script('imageslaoded', get_stylesheet_directory_uri() . '/library/components/imagesloaded/imagesloaded.pkgd.min.js', array('jquery'), '4.1.1', true);
	// Lightbox2
	$lightbox_version = '2.9.0';
	wp_enqueue_script('lightbox2', get_stylesheet_directory_uri() . '/library/components/lightbox2/dist/js/lightbox.min.js', array('jquery'), $lightbox_version, true);
	wp_enqueue_style('ligthbox2', get_stylesheet_directory_uri() . '/library/components/lightbox2/dist/css/lightbox.min.css', array(), $lightbox_version, 'screen');
	// stellar
	wp_enqueue_script('stellar', get_stylesheet_directory_uri() . '/library/components/jquery.stellar/jquery.stellar.min.js', array('jquery'), '0.6.2', true);
	// Animate
	wp_enqueue_style('animate', get_stylesheet_directory_uri() . '/library/components/animate.css/animate.min.css', array(), '3.5.2', 'screen');
	// wow
	wp_enqueue_script('wow', get_stylesheet_directory_uri() . '/library/components/wow/dist/wow.min.js', array(), '1.1.2', true);
	// Dashicons
	wp_enqueue_style('dashicons');
	// app
	wp_enqueue_script('app', get_stylesheet_directory_uri() . '/library/js/app.js', array('jquery'), wp_get_theme()->get('Version'), true);
	wp_enqueue_style('app', get_stylesheet_directory_uri() . '/library/css/app.css', array(), wp_get_theme()->get('Version'), 'screen');
	// jQuery form
	wp_deregister_script('jquery-form');
	wp_enqueue_script('jquery-form', get_stylesheet_directory_uri() . '/library/components/jquery.form/index.js', array('jquery'), '3.51.0', true);
	// WPCF7
	wp_dequeue_style( 'contact-form-7' );
	wp_enqueue_script('wpcf7', get_stylesheet_directory_uri() . '/library/js/lib/wpcf7.js', array('jquery-form'), wp_get_theme()->get('Version'), true);
	// Winsize notifier
	wp_enqueue_script('browsersize-toolip', get_stylesheet_directory_uri() . '/library/components/browsersize-tooltip/dist/browsersize-tooltip.min.js', array(), '1.0.0', true);
}

/**
 * Production ready assets
 */
function production_assets() {
	// jQuery
	wp_deregister_script('jquery');
	// jQuery form
	wp_deregister_script('jquery-form');
	// WPCF7
	wp_dequeue_style( 'contact-form-7' );
	// Dashicons
	wp_enqueue_style('dashicons');
	// app
	wp_enqueue_script('app', get_stylesheet_directory_uri() . '/library/js/app.min.js#asyncload', array(), wp_get_theme()->get('Version'), true);
	wp_enqueue_style('app', get_stylesheet_directory_uri() . '/library/css/app.min.css', array(), wp_get_theme()->get('Version'), 'screen');
}

/* Asynchronous script loading */
function kalabera_async_scripts($url)
{
  if ( strpos( $url, '#asyncload') === false )
    return $url;
  else if ( is_admin() )
    return str_replace( '#asyncload', '', $url );
  else
	return str_replace( '#asyncload', '', $url )."' async='async";
}
add_filter( 'clean_url', 'kalabera_async_scripts', 11, 1 );

/* Dequeue pre-included assets */
function kalabera_dequeue_scripts() {
    // dequeue Contact Form 7 scripts.js
    wp_dequeue_script('contact-form-7');
}
add_action( 'wp_print_scripts', 'kalabera_dequeue_scripts', 100 );

/* Deregister pre-included assets */
function kalabera_deregister_scripts(){
 wp_deregister_script( 'wp-embed' );
 wp_deregister_script('sitepress');
}
add_action( 'wp_footer', 'kalabera_deregister_scripts' );

/* Remove emojis (smileys) that is introduced in WP 4.2 */
function disable_wp_emojicons() {
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
}
add_action( 'init', 'disable_wp_emojicons' );

/*********************
THEME SUPPORT
*********************/

// Adding WP 3+ Functions & Theme Support
function bones_theme_support() {

	// wp thumbnails (sizes handled in functions.php)
	add_theme_support( 'post-thumbnails' );

	// default thumb size
	set_post_thumbnail_size(125, 125, true);

	// wp custom background (thx to @bransonwerner for update)
	add_theme_support( 'custom-background',
	    array(
	    'default-image' => '',    // background image default
	    'default-color' => '',    // background color default (dont add the #)
	    'wp-head-callback' => '_custom_background_cb',
	    'admin-head-callback' => '',
	    'admin-preview-callback' => ''
	    )
	);

	// rss thingy
	add_theme_support('automatic-feed-links');

	// to add header image support go here: http://themble.com/support/adding-header-background-image-support/

	// wp menus
	add_theme_support( 'menus' );

	// registering wp3+ menus
	register_nav_menus(
		array(
			'main-nav' => __( 'The Main Menu', 'kalabera' ),   // main nav in header
			'footer-links' => __( 'Footer Links', 'kalabera' ) // secondary nav in footer
		)
	);

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form'
	) );

} /* end bones theme support */


/*********************
RELATED POSTS FUNCTION
*********************/

// Related Posts Function (call using bones_related_posts(); )
function bones_related_posts() {
	echo '<ul id="bones-related-posts">';
	global $post;
	$tags = wp_get_post_tags( $post->ID );
	if($tags) {
		foreach( $tags as $tag ) {
			$tag_arr .= $tag->slug . ',';
		}
		$args = array(
			'tag' => $tag_arr,
			'numberposts' => 5, /* you can change this to show more */
			'post__not_in' => array($post->ID)
		);
		$related_posts = get_posts( $args );
		if($related_posts) {
			foreach ( $related_posts as $post ) : setup_postdata( $post ); ?>
				<li class="related_post"><a class="entry-unrelated" href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
			<?php endforeach; }
		else { ?>
			<?php echo '<li class="no_related_post">' . __( 'No Related Posts Yet!', 'kalabera' ) . '</li>'; ?>
		<?php }
	}
	wp_reset_postdata();
	echo '</ul>';
} /* end bones related posts function */

/*********************
PAGE NAVI
*********************/

// Numeric Page Navi (built into the theme by default)
function bones_page_navi() {
  global $wp_query;
  $bignum = 999999999;
  if ( $wp_query->max_num_pages <= 1 )
    return;
  echo '<div class="pagination text-center wow fadeInUp">';
  echo paginate_links( array(
    'base'         => str_replace( $bignum, '%#%', esc_url( get_pagenum_link($bignum) ) ),
    'format'       => '',
    'current'      => max( 1, get_query_var('paged') ),
    'total'        => $wp_query->max_num_pages,
    'prev_text'    => '&larr;',
    'next_text'    => '&rarr;',
    'type'         => 'list',
    'end_size'     => 3,
    'mid_size'     => 3
  ) );
  echo '</div>';
} /* end page navi */

/*********************
RANDOM CLEANUP ITEMS
*********************/

// remove the p from around imgs (http://css-tricks.com/snippets/wordpress/remove-paragraph-tags-from-around-images/)
function bones_filter_ptags_on_images($content){
	return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}

// This removes the annoying […] to a Read More link
function bones_excerpt_more($more) {
	global $post;
	// edit here if you like
	return '... <a class="excerpt-read-more link" href="'. get_permalink( $post->ID ) . '" title="'. __( 'Read ', 'kalabera' ) . esc_attr( get_the_title( $post->ID ) ).'">'. __( 'Read more &raquo;', 'kalabera' ) .'</a>';
}

/**
 *  WPML language switcher
 */
function kalabera_language_switcher() {
  if(function_exists('icl_get_languages')) {
    $languages      = icl_get_languages('skip_missing=1');

    $vs_el          = null;
    $dropdown_el    = null;

    if(!empty($languages)) {
      if(count($languages) > 1) {
        foreach($languages as $language) {
          if($language['active']) {
            $vs_el = sprintf('<li><a href="%1$s" title="%2$s">%2$s</a><ul class="menu">', $language['url'], strtoupper($language['language_code']));

          } else {
            $dropdown_el .= sprintf('<li><a href="%1$s" title="%2$s">%2$s</a></li>', $language['url'], strtoupper($language['language_code']));
          }
        }
      } else {
         foreach($languages as $language) {
					 $vs_el = sprintf('<li><a href="%1$s" title="%2$s">%2$s</a>', $language['url'], strtoupper($language['language_code']));
         }
      }

      printf($vs_el);
      printf($dropdown_el);
      if($dropdown_el != null) printf('</ul>');
      printf('</li>');
    }
  }
}

/**
 * Concatinate the website name and description.
 *
 * @return {String} - The concatenated result.
 */
function site_name() {
		return get_bloginfo('name') . ' ' . get_bloginfo('description');
}

/**
 * Adjust the width and height of the Saké icon
 */
function admin_menu_sake_icon() { ?>

<style type="text/css">
	#adminmenu .menu-icon-sake div.wp-menu-image img {
	  width: 20px;
		height: 20px;
	}
</style>
<?php }
add_action( 'admin_head', 'admin_menu_sake_icon' );

/**
 * Allow ACF to use our Google Map API key.
 *
 * @link https://www.advancedcustomfields.com/resources/google-map/
 */
function my_acf_init() {
	acf_update_setting('google_api_key', GOOGLE_API_KEY);
}
add_action('acf/init', 'my_acf_init');


/* Add custom body class */
function funasaka_body_classes($classes) {
    $classes[] = 'init';

    return $classes;
}
add_filter('body_class', 'funasaka_body_classes');

/**
 * Page/Post main banner
 */
function funasaka_banner() { ?>
	<!-- Main Banner -->
	<section class="parallax-wrapper">
		<h2 class="hide"><?php _e('Main Banner', 'kalabera'); ?></h2>
		<div class="banner"
			style="background-image: url(<?php echo esc_url(wp_get_attachment_url(get_post_thumbnail_id())); ?>);"
			data-stellar-ratio="0.6"
			itemscope itemtype="http://schema.org/MediaObject">
		</div>
	</section> <!-- end of: Main Banner -->
<?php }

/*
 * Advanced Custom Fields: Options page
 */
if(function_exists('acf_add_options_page')) {
	acf_add_options_page(array(
			'page_title'  => __('About us', 'kalabera'),
			'menu_title'  => __('About us', 'kalabera'),
			'menu_slug' => 'about-us',
			'parent_slug'   => '',
			'position'      => false,
			'icon_url'      => 'dashicons-nametag',
	));

	// add sub page
	acf_add_options_sub_page(array(
		'page_title' 	=> __('Store Settings', 'kalabera'),
		'menu_title' 	=> __('Store', 'kalabera'),
		'parent_slug' 	=> 'options-general.php',
	));
}
show_admin_bar(false); // hide the admin bar on frontend

?>
